==> surf_lint_rules-1.0.0-dev.1.tar.gz: README.md <==
# Surf Lint Rules

[![Build Status](https://github.com/surfstudio/SurfGear/workflows/build/badge.svg)](https://github.com/surfstudio/SurfGear)
[![Pub Version](https://img.shields.io/pub/v/surf_lint_rules)](https://pub.dev/packages/surf_lint_rules)
[![Pub Version (including pre-releases)](https://img.shields.io/pub/v/surf_lint_rules?include_prereleases)](https://pub.dev/packages/surf_lint_rules)
[![Pub Likes](https://badgen.net/pub/likes/surf_lint_rules)](https://pub.dev/packages/surf_lint_rules)
![Dart Platform](https://badgen.net/pub/dart-platform/surf_lint_rules)
![Flutter Platform](https://badgen.net/pub/flutter-platform/surf_lint_rules)

This package is part of the [SurfGear](https://github.com/surfstudio/SurfGear) toolset made by [Surf](https://surf.ru).

## About

Lint rules for "Surf" company.

## Installation

Add `surf_lint_rules` as dependency to your pubspec.yaml

```yaml
dev_dependencies:
  surf_lint_rules: ^1.0.0
```

You can use both `stable` and `dev` versions of the package listed above in the badges bar.

Create `analysis_options.yaml` file

```yaml
include: package:surf_lint_rules/analysis_options.yaml
```

See the `dartanalyzer` executing the lint checks in you favorite editor.

## Changelog

All notable changes to this project will be documented in [this file](./CHANGELOG.md).

## Issues

For issues, file directly in the [main SurfGear repo](https://github.com/surfstudio/SurfGear).

## Contribute

If you would like to contribute to the package (e.g. by improving the documentation, solving a bug or adding a cool new feature), please review our [contribution guide](../../CONTRIBUTING.md) first and send us your pull request.

You PRs are always welcome.

## How to reach us

Please feel free to ask any questions about this package. Join our community chat on Telegram. We speak English and Russian.

[![Telegram](https://img.shields.io/badge/chat-on%20Telegram-blue.svg)](https://t.me/SurfGear)

## License

[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0)

==> surf_lint_rules-1.1.1-dev.3.tar.gz: README.md <==
# Surf Lint Rules

[![Build Status](https://github.com/surfstudio/SurfGear/workflows/build/badge.svg)](https://github.com/surfstudio/SurfGear)
[![Pub Version](https://img.shields.io/pub/v/surf_lint_rules)](https://pub.dev/packages/surf_lint_rules)
[![Pub Likes](https://badgen.net/pub/likes/surf_lint_rules)](https://pub.dev/packages/surf_lint_rules)
![Dart Platform](https://badgen.net/pub/dart-platform/surf_lint_rules)
![Flutter Platform](https://badgen.net/pub/flutter-platform/surf_lint_rules)

This package is part of the [SurfGear](https://github.com/surfstudio/SurfGear) toolkit made by [Surf](https://surf.ru).

## About

Lint rules for "Surf" company.

## Installation

Add `surf_lint_rules` as dependency to your pubspec.yaml

```yaml
dev_dependencies:
  surf_lint_rules: ^1.0.0
```

You can use both `stable` and `dev` versions of the package listed above in the badges bar.

Create `analysis_options.yaml` file

```yaml
include: package:surf_lint_rules/analysis_options.yaml
```

See the `dartanalyzer` executing the lint checks in you favorite editor.

## Changelog

All notable changes to this project will be documented in [this file](./CHANGELOG.md).

## Issues

For issues, file directly in the [main SurfGear repo](https://github.com/surfstudio/SurfGear).

## Contribute

If you would like to contribute to the package (e.g. by improving the documentation, solving a bug or adding a cool new feature), please review our [contribution guide](../../CONTRIBUTING.md) first and send us your pull request.

Your PRs are always welcome.

## How to reach us

Please feel free to ask any questions about this package. Join our community chat on Telegram. We speak English and Russian.

[![Telegram](https://img.shields.io/badge/chat-on%20Telegram-blue.svg)](https://t.me/SurfGear)

## License

[Apache License, Version 2.0](https://www.apache.org/licenses/LICENSE-2.0)
